@@ -89,6 +89,7 @@ func TestOpVarConst(t *testing.T) {
 		{src: "b := uint(5); a+b", res: "15"},
 		{src: "b := uint(5); b+a", res: "15"},
 		{src: "b := uint(5); b>a", res: "false"},
+		{src: "const maxlen = cap(aa); var aa = []int{1,2}", err: "1:20: constant definition loop"},
 	})
 }
 
@@ -102,6 +103,16 @@ func TestEvalStar(t *testing.T) {
 
 func TestEvalAssign(t *testing.T) {
 	i := interp.New(interp.Options{})
+	i.Use(interp.Exports{
+		"testpkg": {
+			"val": reflect.ValueOf(int64(11)),
+		},
+	})
+	_, e := i.Eval(`import "testpkg"`)
+	if e != nil {
+		t.Fatal(e)
+	}
+
 	runTests(t, i, []testCase{
 		{src: `a := "Hello"; a += " world"`, res: "Hello world"},
 		{src: `b := "Hello"; b += 1`, err: "1:42: invalid operation: mismatched types string and int"},
@@ -111,6 +122,7 @@ func TestEvalAssign(t *testing.T) {
 		{src: "g := 1; g <<= 8", res: "256"},
 		{src: "h := 1; h >>= 8", res: "0"},
 		{src: "i := 1; j := &i; (*j) = 2", res: "2"},
+		{src: "i64 := testpkg.val; i64 == 11", res: "true"},
 	})
 }
 
@@ -495,12 +507,19 @@ func TestEvalMethod(t *testing.T) {
 			Hello() string
 		}
 
+		type Hey interface {
+			Hello() string
+		}
+
 		func (r *Root) Hello() string { return "Hello " + r.Name }
 
 		var r = Root{"R"}
 		var o = One{r}
-		var root interface{} = &Root{Name: "test1"}
-		var one interface{} = &One{Root{Name: "test2"}}
+		// TODO(mpl): restore empty interfaces when type assertions work (again) on them.
+		// var root interface{} = &Root{Name: "test1"}
+		// var one interface{} = &One{Root{Name: "test2"}}
+		var root Hey = &Root{Name: "test1"}
+		var one Hey = &One{Root{Name: "test2"}}
 	`)
 	runTests(t, i, []testCase{
 		{src: "r.Hello()", res: "Hello R"},
@@ -741,6 +760,8 @@ func TestEvalWithContext(t *testing.T) {
 }
 
 func runTests(t *testing.T, i *interp.Interpreter, tests []testCase) {
+	t.Helper()
+
 	for _, test := range tests {
 		t.Run(test.desc, func(t *testing.T) {
 			if test.skip != "" {
@@ -770,6 +791,8 @@ func eval(t *testing.T, i *interp.Interpreter, src string) reflect.Value {
 }
 
 func assertEval(t *testing.T, i *interp.Interpreter, src, expectedError, expectedRes string) {
+	t.Helper()
+
 	res, err := i.Eval(src)
 
 	if expectedError != "" {
@@ -1148,6 +1171,8 @@ func TestConcurrentComposite2(t *testing.T) {
 }
 
 func testConcurrentComposite(t *testing.T, filePath string) {
+	t.Helper()
+
 	if testing.Short() {
 		return
 	}
